searchData={"items":[{"type":"module","title":"PhoenixFormAwesomplete","doc":"PhoenixFormAwesomplete is a [Phoenix form helper](https://hexdocs.pm/phoenix_html/Phoenix.HTML.Form.html) \nthat utilizes Lea Verou's autocomplete / autosuggest / typeahead / \ninputsearch [Awesomplete widget](https://leaverou.github.io/awesomplete/index.html).\n\nIt comes with an AwesompleteUtil [javascript library](https://nico-amsterdam.github.io/awesomplete-util/index.html) \nwhich adds the following features:\n\n- Dynamic remote data loading; based on what is typed-in it performs an ajax lookup.\n- Allow HTML markup in the shown items. Show value with description. Optionally search in the description text.\n- Show when there is an exact match.\n- Show when there isn't a match.\n- When there is an exact match show related data (supplied in the remote data) in other parts of the page.\n- Select the highlighted item with the tab-key.","ref":"PhoenixFormAwesomplete.html"},{"type":"module","title":"Example - PhoenixFormAwesomplete","doc":"iex> {:safe, [input, script]} = PhoenixFormAwesomplete.awesomplete(:user, :drinks,\n    ...> [\"data-list\": \"beer, gin, soda, sprite, water, vodga, whine, whisky\"], \n    ...> %{ minChars: 1 } )\n    iex> to_string input\n    \" \n    \" id=\\\"user_drinks\\\" name=\\\"user[drinks]\\\" type=\\\"text\\\">\"\n    iex> script\n    \" AwesompleteUtil.start('#user_drinks', {}, {minChars: 1}); \"\n\nThe first three parameters are passed on unchanged to the Phoenix form [text_input](https://hexdocs.pm/phoenix_html/Phoenix.HTML.Form.html#text_input/3) which generates the input tag.\n`minChars` is an option for the Awesomplete object which is started with inline javascript.\nJust adding the `multiple` option changes the generated javascript code completely, the PhoenixFormAwesomplete module\ntakes care of that. \nInstead of an server side generated data-list it is possible to specify an url of a JSON web service and \nlet the client-code lookup the data list on-demand while typing. \nLook at the [live examples](https://nico-amsterdam.github.io/awesomplete-util/phoenix.html) with code.\n\n\nIt is possible to use aliases for the javascript library references in the generated code \nvia the environment variables `util` and `awesomplete`.\nThe default names, `AwesompleteUtil` and `Awesomplete` respectively, are a bit long.\nThis can shorten the average page size.\nFor example use this javascript: \n     var AU = AwesompleteUtil, AW = Awesomplete; \nand change the variables via the application config:\n     :phoenix_form_awesomplete, util:         \"AU\"\n     :phoenix_form_awesomplete, awesomplete:  \"AW\"\nAfter changing the config/config.exs run:\n     mix deps.compile --force phoenix_form_awesomplete","ref":"PhoenixFormAwesomplete.html#module-example"},{"type":"function","title":"PhoenixFormAwesomplete.awesomplete/4","doc":"This method generates an input tag and inline javascript code that starts Awesomplete.\n\nAwesomplete options:\n * `ajax`            - Replace ajax function. Supplied function receives these parameters: (url, urlEnd, val, fn, xhr). fn is the callback function. Default: AwesompleteUtil.ajax. \n * `assign`          - Assign the Awesomplete object to a variable. true/false/name. If true the variable name will 'awe\\_' + id of input tag. Default: false\n * `autoFirst`       - Automatically select the first element. Default: false. \n * `combobox`        - Id of the combobox button. true/false/id. If true the assumed button id is 'awe\\_btn\\_' + id of the input tag. Default: false\n * `convertInput`    - Convert input function. Internally convert input for comparison with the data list items. By default it trims the input and converts it to lowercase for a case-insensitive comparison.\n * `convertResponse` - Convert JSON response from ajax calls. This function is called with the parsed JSON, and allows conversion of the data before further processing. Default: nil - no conversion. \n * `data`            - Data function as defined in [Awesomplete](http://leaverou.github.io/awesomplete/index.html#extensibility)\n * `descr`           - Name of the field in the data list (the JSON response) that contains the description text to show below the value in the suggestion list. Default: no description\n * `descrSearch`     - Filter must also search the input value in the description field. Default: false\n * `value`           - Name of the field in the data list (the JSON response) that contains the value.\n * `filter`          - Filter function as defined in [Awesomplete](http://leaverou.github.io/awesomplete/index.html#extensibility). Mostly Awesomplete.FILTER\\_STARTSWITH or Awesomplete.FILTER\\_CONTAINS. If label is different as value, filter on value with AweompleteUtil.filterStartsWith or AwesompleteUtil.filterContains.\n * `item`            - Item function as defined in [Awesomplete](http://leaverou.github.io/awesomplete/index.html#extensibility). Default is to highlight all occurrences of the input text. Use AwesompleteUtil.itemStartsWith if that matches with the used filter.\n * `label`           - Name of the field in the data list (the JSON response) that contains the text that should be shown instead of the value. \n * `list`            - Data list as defined in [Awesomplete](http://leaverou.github.io/awesomplete/index.html#extensibility).\n * `loadall`         - Data list contains all items. The input value will not be used in ajax calls. Default: false\n * `limit`           - number. If a limit is specified, and the number of items returned by the server is equal or more as this limit, the AwesompleteUtil code assumes that there are more results, so it will re-query if more characters are typed to get more refined results. The limit:1 tells that not more than 1 result is expected, so the json service doesn’t have to return an array. With limit:0 it will always re-query if more characters are typed. Default: no limit \n * `maxItems`        - Maximum number of suggestions to display. Default: 10 \n * `minChars`        - Minimum characters the user has to type before the autocomplete popup shows up. Default: 2 \n * `multiple`        - true/false/characters. Separators to allow multiple values. If true, the separator will be the space character. Default: false\n * `prepop`          - true/false. If true do lookup initial/autofilled value and send awesomplete-prepop event. Default: false \n * `replace`         - Replace function as defined in [Awesomplete](http://leaverou.github.io/awesomplete/index.html#extensibility)\n * `sort`            - Sort function as defined in [Awesomplete](http://leaverou.github.io/awesomplete/index.html#extensibility)\n * `url`             - url for ajax calls.\n * `urlEnd`          - Addition at the end of the url of the ajax call, after the input value.","ref":"PhoenixFormAwesomplete.html#awesomplete/4"},{"type":"function","title":"Example - PhoenixFormAwesomplete.awesomplete/4","doc":"iex> {:safe, [inp, scr]} = PhoenixFormAwesomplete.awesomplete(:user, :eyes, \n    ...> [\"data-list\": \"blue, brown, green\"],\n    ...>  %{ minChars: 1, multiple: \",;\" } )\n    iex> to_string inp\n    \" \"\n    iex> scr\n    \" AwesompleteUtil.start('#user_eyes', \"   \n    \"{convertInput: function(input) {\"  \n    \" return input.replace(/[,;]\\\\s*$/, '').match(/[^,;]*$/)[0].trim().toLowerCase(); }}, \"  \n    \"{minChars: 1, \"   \n    \"replace: function(data) {\"  \n    \" var text=data.value;\"   \n    \" this.input.value = this.input.value.match(/^.+[,;]\\\\s*|/)[0] + text + ', '; }, \"  \n    \"filter: function(data, input) {\"  \n    \" return Awesomplete.FILTER_CONTAINS(data, input.match(/[^,;]*([,;]\\\\s*)?$/)[0]); }, \"  \n    \"item: function(text, input) {\"  \n    \" return AwesompleteUtil.itemContains(text, input.match(/[^,;]*([,;]\\\\s*)?$/)[0]); }});\"  \n    \" \"","ref":"PhoenixFormAwesomplete.html#awesomplete/4-example"},{"type":"function","title":"PhoenixFormAwesomplete.awesomplete_js/3","doc":"This method generates javascript code for using Awesomplete(Util).","ref":"PhoenixFormAwesomplete.html#awesomplete_js/3"},{"type":"function","title":"Example - PhoenixFormAwesomplete.awesomplete_js/3","doc":"iex> PhoenixFormAwesomplete.awesomplete_js(:user, :hobby, %{ minChars: 1 } )    \n    \"AwesompleteUtil.start('#user_hobby', {}, {minChars: 1});\"","ref":"PhoenixFormAwesomplete.html#awesomplete_js/3-example"},{"type":"function","title":"PhoenixFormAwesomplete.awesomplete_script/3","doc":"This method generates a script tag with javascript code for using Awesomplete(Util).","ref":"PhoenixFormAwesomplete.html#awesomplete_script/3"},{"type":"function","title":"Example - PhoenixFormAwesomplete.awesomplete_script/3","doc":"iex> PhoenixFormAwesomplete.awesomplete_script(:user, :hobby, %{ minChars: 1 } )\n    {:safe,\n     \" AwesompleteUtil.start('#user_hobby', {}, {minChars: 1}); \"}","ref":"PhoenixFormAwesomplete.html#awesomplete_script/3-example"},{"type":"function","title":"PhoenixFormAwesomplete.copy_to_field/5","doc":"Create script tag with javascript that listens to `awesomplete-prepop` and `awesomplete-match` events,\nand copies the `data_field` to the target field.","ref":"PhoenixFormAwesomplete.html#copy_to_field/5"},{"type":"function","title":"Example - PhoenixFormAwesomplete.copy_to_field/5","doc":"iex> PhoenixFormAwesomplete.copy_to_field(:user, :color, \"label\", :door, :paint)  \n    {:safe,\n     \" AwesompleteUtil.startCopy('#user_color', 'label', '#door_paint'); \"}","ref":"PhoenixFormAwesomplete.html#copy_to_field/5-example"},{"type":"function","title":"PhoenixFormAwesomplete.copy_to_id/4","doc":"Create script tag with javascript that listens to `awesomplete-prepop` and `awesomplete-match` events,\nand copies the `data_field` to the DOM element with the given target id.\nThe `target_id` can also be a javascript function. This function receives two parameters: event and dataField. The event detail property contains an array with the matching list item. The array is empty when there is no match.","ref":"PhoenixFormAwesomplete.html#copy_to_id/4"},{"type":"function","title":"Example - PhoenixFormAwesomplete.copy_to_id/4","doc":"iex> PhoenixFormAwesomplete.copy_to_id(:user, :color, \"label\", \"#awe-color-result\") \n    {:safe,\n     \" AwesompleteUtil.startCopy('#user_color', 'label', '#awe-color-result'); \"}","ref":"PhoenixFormAwesomplete.html#copy_to_id/4-example"},{"type":"function","title":"PhoenixFormAwesomplete.copy_to_id_js/4","doc":"Create javascript that listens to `awesomplete-prepop` and `awesomplete-match` events,\nand copies the `data_field` to the DOM element with the given target id.\nThe `target_id` can also be a javascript function.","ref":"PhoenixFormAwesomplete.html#copy_to_id_js/4"},{"type":"function","title":"Example - PhoenixFormAwesomplete.copy_to_id_js/4","doc":"iex> PhoenixFormAwesomplete.copy_to_id_js(:user, :color, \"label\", \"#awe-color-result\") \n    \"AwesompleteUtil.startCopy('#user_color', 'label', '#awe-color-result');\"","ref":"PhoenixFormAwesomplete.html#copy_to_id_js/4-example"},{"type":"function","title":"PhoenixFormAwesomplete.script/1","doc":"Create script tag with the supplied script. No defer or async because this is used for inline script.","ref":"PhoenixFormAwesomplete.html#script/1"},{"type":"function","title":"Example - PhoenixFormAwesomplete.script/1","doc":"iex> PhoenixFormAwesomplete.script(\"alert(1);\")\n    {:safe, \" alert(1); \"}","ref":"PhoenixFormAwesomplete.html#script/1-example"},{"type":"module","title":"PhoenixFormAwesomplete.GenJS","doc":"Generate the javascript code for PhoenixFormAwesomplete.","ref":"PhoenixFormAwesomplete.GenJS.html"},{"type":"module","title":"Example - PhoenixFormAwesomplete.GenJS","doc":"iex> PhoenixFormAwesomplete.GenJS.awesomplete_js(\"user_drinks\", %{ minChars: 1, prepop: true } )\n    \"AwesompleteUtil.start('#user_drinks', {prepop: true}, {minChars: 1});\"","ref":"PhoenixFormAwesomplete.GenJS.html#module-example"},{"type":"function","title":"PhoenixFormAwesomplete.GenJS.awesomplete_js/2","doc":"This method generates javascript code for using Awesomplete(Util).","ref":"PhoenixFormAwesomplete.GenJS.html#awesomplete_js/2"},{"type":"function","title":"Example - PhoenixFormAwesomplete.GenJS.awesomplete_js/2","doc":"iex> PhoenixFormAwesomplete.GenJS.awesomplete_js(\"user_hobby\", %{ minChars: 1 } ) \n    \"AwesompleteUtil.start('#user_hobby', {}, {minChars: 1});\"","ref":"PhoenixFormAwesomplete.GenJS.html#awesomplete_js/2-example"},{"type":"function","title":"PhoenixFormAwesomplete.GenJS.copy_to_id_js/3","doc":"Create javascript that listens to `awesomplete-prepop` and `awesomplete-match` events,\nand copies the `data_field` to the DOM element with the given target id.\nThe `target_id` can also be a javascript function.","ref":"PhoenixFormAwesomplete.GenJS.html#copy_to_id_js/3"},{"type":"function","title":"Example - PhoenixFormAwesomplete.GenJS.copy_to_id_js/3","doc":"iex> PhoenixFormAwesomplete.GenJS.copy_to_id_js(\"#user_color\", \"label\", \"#awe-color-result\") \n    \"AwesompleteUtil.startCopy('#user_color', 'label', '#awe-color-result');\"","ref":"PhoenixFormAwesomplete.GenJS.html#copy_to_id_js/3-example"}],"content_type":"text/markdown"}